@@ -8,7 +8,7 @@ def validator_decorator(func):
         _fun_name = func.__name__
 
         if self._validate:
-            self._validate(_class_name, _fun_name)
+            self._validate(_class_name, _fun_name, **kwargs)
 
         return func(self, **kwargs)
 
